@@ -3,13 +3,14 @@ from pathlib import Path
 from docutils.parsers.rst import directives
 from docutils import nodes
 from sphinx.util import logging
-import sass
 from bs4 import BeautifulSoup as bs
-
+from sass import compile as sass_compile
 
 from .launch import add_hub_urls
 
-__version__ = "0.0.34"
+__version__ = "0.0.36"
+"""sphinx-book-theme version"""
+
 SPHINX_LOGGER = logging.getLogger(__name__)
 
 
@@ -23,6 +24,13 @@ def add_static_path(app):
     static_path = Path(__file__).parent.joinpath("static").absolute()
     app.config.html_static_path.append(str(static_path))
 
+    # Compile the css file if it's not been compiled already
+    compiled_css_file = static_path / "sphinx-book-theme.css"
+    if not compiled_css_file.exists():
+        source_dir = str(static_path.parent / "scss")
+        output_dir = str(static_path)
+        sass_compile(dirname=(source_dir, output_dir), output_style="compressed")
+
 
 def find_url_relative_to_root(pagename, relative_page, path_docs_source):
     """Given the current page (pagename), a relative page to it (relative_page),
@@ -276,13 +284,6 @@ def _string_or_bool(var):
         return var is None
 
 
-def compile_scss():
-    path_css_folder = Path(__file__).parent.joinpath("static")
-    scss = path_css_folder.joinpath("sphinx-book-theme.scss")
-    css = sass.compile(filename=str(scss))
-    path_css_folder.joinpath("sphinx-book-theme.css").write_text(css)
-
-
 class Margin(directives.body.Sidebar):
     """Goes in the margin to the right of the page."""
 
@@ -290,6 +291,7 @@ class Margin(directives.body.Sidebar):
     required_arguments = 0
 
     def run(self):
+        """Run the directive."""
         if not self.arguments:
             self.arguments = [""]
         nodes = super().run()
@@ -302,7 +304,6 @@ class Margin(directives.body.Sidebar):
 
 
 def setup(app):
-    compile_scss()
     app.connect("env-before-read-docs", update_thebe_config)
 
     # Configuration for Juypter Book
